==> client-java-api-8.0.0-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1HTTPIngressPathBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkingV1beta1HTTPIngressPathBuilder extends NetworkingV1beta1HTTPIngressPathFluentImpl<NetworkingV1beta1HTTPIngressPathBuilder> implements VisitableBuilder<NetworkingV1beta1HTTPIngressPath,NetworkingV1beta1HTTPIngressPathBuilder>{

    NetworkingV1beta1HTTPIngressPathFluent<?> fluent;
    Boolean validationEnabled;

    public NetworkingV1beta1HTTPIngressPathBuilder(){
            this(true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(Boolean validationEnabled){
            this(new NetworkingV1beta1HTTPIngressPath(), validationEnabled);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent){
            this(fluent, true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NetworkingV1beta1HTTPIngressPath(), validationEnabled);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent,NetworkingV1beta1HTTPIngressPath instance){
            this(fluent, instance, true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent,NetworkingV1beta1HTTPIngressPath instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withBackend(instance.getBackend());

            fluent.withPath(instance.getPath());

            this.validationEnabled = validationEnabled; 
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPath instance){
            this(instance,true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPath instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withBackend(instance.getBackend());

            this.withPath(instance.getPath());

            this.validationEnabled = validationEnabled; 
    }

    public NetworkingV1beta1HTTPIngressPath build(){
            NetworkingV1beta1HTTPIngressPath buildable = new NetworkingV1beta1HTTPIngressPath();
            buildable.setBackend(fluent.getBackend());
            buildable.setPath(fluent.getPath());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NetworkingV1beta1HTTPIngressPathBuilder that = (NetworkingV1beta1HTTPIngressPathBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1HTTPIngressPathBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkingV1beta1HTTPIngressPathBuilder extends NetworkingV1beta1HTTPIngressPathFluentImpl<NetworkingV1beta1HTTPIngressPathBuilder> implements VisitableBuilder<NetworkingV1beta1HTTPIngressPath,NetworkingV1beta1HTTPIngressPathBuilder>{

    NetworkingV1beta1HTTPIngressPathFluent<?> fluent;
    Boolean validationEnabled;

    public NetworkingV1beta1HTTPIngressPathBuilder(){
            this(true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(Boolean validationEnabled){
            this(new NetworkingV1beta1HTTPIngressPath(), validationEnabled);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent){
            this(fluent, true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NetworkingV1beta1HTTPIngressPath(), validationEnabled);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent,NetworkingV1beta1HTTPIngressPath instance){
            this(fluent, instance, true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPathFluent<?> fluent,NetworkingV1beta1HTTPIngressPath instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withBackend(instance.getBackend());

            fluent.withPath(instance.getPath());

            fluent.withPathType(instance.getPathType());

            this.validationEnabled = validationEnabled; 
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPath instance){
            this(instance,true);
    }
    public NetworkingV1beta1HTTPIngressPathBuilder(NetworkingV1beta1HTTPIngressPath instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withBackend(instance.getBackend());

            this.withPath(instance.getPath());

            this.withPathType(instance.getPathType());

            this.validationEnabled = validationEnabled; 
    }

    public NetworkingV1beta1HTTPIngressPath build(){
            NetworkingV1beta1HTTPIngressPath buildable = new NetworkingV1beta1HTTPIngressPath();
            buildable.setBackend(fluent.getBackend());
            buildable.setPath(fluent.getPath());
            buildable.setPathType(fluent.getPathType());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NetworkingV1beta1HTTPIngressPathBuilder that = (NetworkingV1beta1HTTPIngressPathBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
